@@ -190,7 +190,7 @@ LM23i=function(trat,
                                rmse))
   graficos=list("Coefficients"=models,
                 "values"=graphs,
-                grafico,
+                "plot"=grafico,
                 "VIF"=vif)
-  print(graficos)
+  graficos
 }
