@@ -199,6 +199,6 @@ beta_reg=function(trat,
                                rmse))
   graficos=list("Coefficients"=coef,
                 "values"=graphs,
-                graph)
-  print(graficos)
+                "plot"=graph)
+  graficos
 }
